@@ -75,7 +75,7 @@ class MaemoReactor(object):
         while not done:
             shuffle(games)
             for i in games:
-                l.append(self.getGameWithName(i))
+                l.append(i)
                 counter += 1
                 if counter == number:
                     done = True
@@ -84,7 +84,7 @@ class MaemoReactor(object):
     
     def getGameWithName(self, game):
         '''returns a new minigame with the given name'''
-        #~ return flaggame.FlagGame(self)
+        #~ return minsymbolsgame.MinSymbolsGame(self)
         if game == "ColorGame":
             return colorgame.ColorGame(self)
         if game == "CrashGame":
@@ -159,7 +159,7 @@ class MaemoReactor(object):
             for g in games:
                 if returnToMenu: break
                 self.clearPlayArea()
-                self.g = g
+                self.g = self.getGameWithName(g)
                 self.button1.setColor((0, 71, 171))
                 self.button2.setColor((0, 71, 171))
                 self.button1.caption = False
@@ -298,11 +298,20 @@ class MaemoReactor(object):
     
     def drawScore(self):
         '''draws the small score numbers into the corners'''
-        textFont = pygame.font.Font(None, 40)
+        textSize = 40
+        textFont = pygame.font.Font(None, textSize)
+        w = self.screen.get_width()
+        h = self.screen.get_height()
         text = textFont.render(str(self.points1), 1, (200,200,200))
+        text = pygame.transform.rotate(text, -90)
         self.screen.blit(text, (165, 5))
+        text = pygame.transform.rotate(text, 180)
+        self.screen.blit(text, (w/2-textSize, h-5-text.get_height()))
         text = textFont.render(str(self.points2), 1, (200,200,200))
-        self.screen.blit(text, (self.screen.get_width()-185, 5))
+        text = pygame.transform.rotate(text, 90)
+        self.screen.blit(text, (w-190,  h-5-text.get_height()))
+        text = pygame.transform.rotate(text, 180)
+        self.screen.blit(text, (w/2+textSize, 5))
     
     def drawText(self, text, center, width, orientation=None,
                  color=None, size=None):
